==> fltk-1.4.3-docs-html.tar.gz: fltk-1.4.3/share/doc/fltk/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "FLTK 1.4.3", "index.html", [
    [ "FLTK Programming Manual", "index.html", "index" ],
    [ "Fl_Terminal Technical Documentation", "Fl_Terminal_Tech_Docs.html", [
      [ "The Escape Codes Fl_Terminal Supports", "Fl_Terminal_Tech_Docs.html#Fl_Terminal_escape_codes", null ],
      [ "Useful Terminal Escape Code Documentation", "Fl_Terminal_Tech_Docs.html#external_escape_codes", null ],
      [ "Fl_Terminal Design Document", "Fl_Terminal_Tech_Docs.html#Fl_Terminal_design", null ]
    ] ],
    [ "Development of the FLTK library", "FLTK-devel.html", "FLTK-devel" ],
    [ "Todo List", "todo.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Enumerations_8H.html",
"Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca2b01bc412ce880449f7874d1b56d31ab",
"Fl__Overlay__Window_8H_source.html",
"classFl__Bitmap.html",
"classFl__Clock__Output.html#a23a19dd0d8f5289c18d331a2e3c0ad35",
"classFl__Gl__Window.html#a37e4b342cf03156ad2aeba672f98405b",
"classFl__Input__.html#a556564992147b124c374f27a6afc5b67",
"classFl__Pack.html#ab9d5ae04d8e59003c7a6c97b6344cb09",
"classFl__Rect.html#abe47895601a5e7c21000916819428bce",
"classFl__Table.html#a6eb5e914ea4ec3a97a50608cddeef3f0",
"classFl__Terminal.html#aa790e1c3be555a4ad5e25dfaa303528eab4b4dbbaf764eaec321fac5b7fefcb17",
"classFl__Text__Display.html#a91e871bc1f1ba50fb19b3841bbf96058",
"classFl__Tree.html#ab2f7368ebf2385b10078a79109423c50",
"classFl__Valuator.html#a774d8cc1d4751c5363bc0d45abff9f07",
"classFl__Window.html#a72f5733f13cb6d8b646f1e7ffcd92333",
"examples.html#examples_subwindow",
"globals_func_c.html",
"group__fl__drawings.html#gaddd54f4825f59dd36fd16fafae0a49c2",
"iso8859__8_8h_source.html",
"structFl__Scroll_1_1Fl__Region__XYWH.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> fltk-1.4.4-docs-html.tar.gz: fltk-1.4.4/share/doc/fltk/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "FLTK 1.4.4", "index.html", [
    [ "FLTK Programming Manual", "index.html", "index" ],
    [ "Fl_Terminal Technical Documentation", "Fl_Terminal_Tech_Docs.html", [
      [ "The Escape Codes Fl_Terminal Supports", "Fl_Terminal_Tech_Docs.html#Fl_Terminal_escape_codes", null ],
      [ "Useful Terminal Escape Code Documentation", "Fl_Terminal_Tech_Docs.html#external_escape_codes", null ],
      [ "Fl_Terminal Design Document", "Fl_Terminal_Tech_Docs.html#Fl_Terminal_design", null ]
    ] ],
    [ "Development of the FLTK library", "FLTK-devel.html", "FLTK-devel" ],
    [ "Todo List", "todo.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", "globals_eval" ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Enumerations_8H.html",
"Enumerations_8H.html#ae48bf9070f8541de17829f54ccacc6bca29a40628cb975d91b49bc71571b64a70",
"Fl__Overlay__Window_8H_source.html",
"classFl__Bitmap.html",
"classFl__Clock__Output.html#a23a19dd0d8f5289c18d331a2e3c0ad35",
"classFl__Gl__Window.html#a37e4b342cf03156ad2aeba672f98405b",
"classFl__Input__.html#a43df8f9c6c70c1abc7097156526341a1",
"classFl__Pack.html#a584abf6ceafdd649fe5ab3dd5f337b79",
"classFl__Rect.html#ab659444a28cb9c00b42a27c14338c57e",
"classFl__Table.html#a6d89cb4006a9147b01c69c04ffee9499",
"classFl__Terminal.html#aa423bee854c3e47bdb8809346a60f159",
"classFl__Text__Display.html#a8695a84858aa91aef4323f4618cab9b7",
"classFl__Tree.html#aa5db7dde89d8da65664520b0feb462c9",
"classFl__Valuator.html#a5613cf279b22517abd564a54ef15e021",
"classFl__Window.html#a615bf5d04b79df5c8f53f3dcdf19e9b5",
"examples.html#examples_resizebox",
"globals_func.html",
"group__fl__drawings.html#gad752f20cc18c2618b5130272764e0f0d",
"iso8859__5_8h_source.html",
"structFl__Scroll_1_1Fl__Region__LRTB.html#a4b025c0301af8bad486e00db5c808f16"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
